@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: controls.h,v 1.21 2004/12/21 21:12:45 mbarbon Exp $
-// Copyright:   (c) 2000-2004 Mattia Barbon
+// RCS-ID:      $Id: controls.h,v 1.22 2006/12/03 14:56:38 mbarbon Exp $
+// Copyright:   (c) 2000-2004, 2006 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -27,6 +27,9 @@ public:
     wxString OnGetItemText( long item, long column ) const;
     int OnGetItemImage( long item ) const;
     wxListItemAttr* OnGetItemAttr( long item ) const;
+#if WXPERL_W_VERSION_GE( 2, 7, 2 )
+    DEC_V_CBACK_INT__LONG_LONG_const( OnGetItemColumnImage );
+#endif
 };
 
 class wxPliTreeCtrl:public wxTreeCtrl
